@@ -6,6 +6,7 @@ import Package
 bugsCmd :: Maybe String -> [String] -> IO ()
 bugsCmd keyword pkgs = do
   if null pkgs
+    -- FIXME check for distgit
     then bugsPkg "."
     else mapM_ bugsPkg pkgs
   where
@@ -17,5 +18,5 @@ bugsCmd keyword pkgs = do
             case keyword of
               Nothing -> statusOpen
               Just key -> statusOpen .&&. summaryContains key
-      (bugs, _) <- bugsSession $ pkgBugs (unPackage pkg) .&&. query
+      bugs <- bugsAnon $ pkgBugs (unPackage pkg) .&&. query
       mapM_ putBugVer $ sortBugsByProduct bugs
