@@ -7,11 +7,20 @@ module Common.System (
   getDirectoryName,
   isTty,
   setNoBuffering,
+#if !MIN_VERSION_filepath(1,4,2)
+  isExtensionOf,
+#endif
 #if !MIN_VERSION_simple_cmd(0,2,3)
-  cmdFull
+  cmdFull,
+#endif
+#if !MIN_VERSION_simple_cmd(0,2,5)
+  timeIO,
 #endif
   ) where
 
+#if !MIN_VERSION_filepath(1,4,2)
+import Data.List
+#endif
 import SimpleCmd
 #if MIN_VERSION_simple_cmd(0,2,1)
   hiding (ifM,whenM)
@@ -24,6 +33,21 @@ import System.Directory
 import System.FilePath
 import System.IO
 
+#if !MIN_VERSION_simple_cmd(0,2,5)
+import Control.Exception
+import Data.Time.Clock
+
+timeIO :: IO a -> IO a
+timeIO action = do
+  bracket
+    getCurrentTime
+    (\start -> do
+        end <- getCurrentTime
+        let duration = diffUTCTime end start
+        putStrLn $ "took " ++ show duration)
+    (const action)
+#endif
+
 isTty :: IO Bool
 isTty = hIsTerminalDevice stdin
 
@@ -48,3 +72,9 @@ cmdFull c args input = do
       then init str
       else str
 #endif
+
+#if !MIN_VERSION_filepath(1,4,2)
+isExtensionOf :: String -> FilePath -> Bool
+isExtensionOf ext@('.':_) = isSuffixOf ext . takeExtensions
+isExtensionOf ext         = isSuffixOf ('.':ext) . takeExtensions
+#endif
