@@ -1,19 +1,19 @@
 module Pagure (
   srcfpo,
   pagureio,
-  pagureProjectInfo,
   pagureListGitBranches,
   pagureListProjectIssueTitlesStatus,
   IssueTitleStatus(..),
+  pagureProjectInfo,
   pagureUserRepos,
   makeItem,
   printScmIssue
   ) where
 
+import Common ((+/+))
 import qualified Common.Text as T
 
 import Fedora.Pagure
-import System.FilePath
 
 srcfpo :: String
 srcfpo = "src.fedoraproject.org"
@@ -23,6 +23,6 @@ pagureio = "pagure.io"
 
 printScmIssue :: IssueTitleStatus -> IO ()
 printScmIssue issue =
-  putStrLn $ "https://" ++ pagureio </> "releng/fedora-scm-requests" </> "issue" </> show (pagureIssueId issue) ++ " (" ++ T.unpack (pagureIssueStatus issue) ++ mclosed ++ "): " ++ pagureIssueTitle issue
+  putStrLn $ "https://" ++ pagureio +/+ "releng/fedora-scm-requests" +/+ "issue" +/+ show (pagureIssueId issue) ++ " (" ++ T.unpack (pagureIssueStatus issue) ++ mclosed ++ "): " ++ pagureIssueTitle issue
   where
     mclosed = maybe "" (\s-> ":" ++ T.unpack s) $ pagureIssueCloseStatus issue
